@@ -4,25 +4,23 @@
 #' @param df The data.frame of values.
 #' @param selected Currently selected row.
 #' @examples
-#' inp <- "C:/Users/jlisec/Documents/Projects/BAMTool_Backup/DRMD/drmc-007.xml"
-#' tab <- eCerto:::read_drmd_xml(inp)
-#' tab <- eCerto:::xml2df(tab, type = "admin")
-#' out_dt <- eCerto:::style_tabD1(df = tab, selected = NULL)
-#' out_dt
+#' df <- data.frame(
+#'   path = paste0("Path", 1:5),
+#'   idx = c("1_1_1_1","1_1_2_1","1_2_1_1","1_2_2_1","1_3_1_1"),
+#'   value = paste0("Value", 1:5)
+#' )
+#' eCerto:::styleTabD1(df = tab, selected = NULL)
 #' @return A datatable object.
 #' @keywords internal
 #' @noRd
 styleTabD1 <- function(df, selected = 1) {
   e_msg("Styling Tab.D1 for HTML output")
-  # ====
-  # old Version
-  # df <- plyr::ldply(1:nrow(df), function(i) {
-  #   x <- rev(stats::na.omit(unlist(df[i,])))
-  #   data.frame("Last_level" = x[2], "value" = x[1])
-  # })
-  # new version
+
+  # hide first column ("path")
   df <- df[,-1, drop=FALSE]
-  # ====
+
+  # convert column 'idx' for better display
+  df[,"idx"] <- format_hierarchy(df[,"idx"])
 
   # create DT object
   dt <- DT::datatable(
@@ -33,5 +31,7 @@ styleTabD1 <- function(df, selected = 1) {
     selection = list(mode = "single", selected = selected, target = 'row')
   )
 
+  dt <- DT::formatStyle(dt, 'idx', fontFamily = 'monospace')
+
   return(dt)
 }
