@@ -3,9 +3,9 @@
 #' @details tbd.
 #' @param df The data.frame of values.
 #' @examples
-#' inp <- "C:/Users/jlisec/Documents/Projects/BAMTool_Backup/DRMD/drmc-007.xml"
-#' tab <- eCerto:::read_drmd_xml(inp)
-#' tab <- eCerto:::xml2df(tab, type = "full")
+#' fl <- system.file("extdata", "drmd", "BAM-M375a.xml", package = "eCerto")
+#' lst <- eCerto:::read_drmd_xml(fl)
+#' tab <- eCerto:::flatten_list_to_df(lst)
 #' out_dt <- eCerto:::styleTabD3(df = tab)
 #' out_dt
 #' @return A datatable object.
@@ -14,13 +14,22 @@
 styleTabD3 <- function(df, interact_ele = TRUE) {
   e_msg("Styling Tab.D3 for HTML output")
 
+  # hide first column ("path")
+  df <- df[,-1, drop=FALSE]
+
+  # convert column 'idx' for better display
+  df[,"idx"] <- format_hierarchy(df[,"idx"])
+
   # create DT object
   dt <- DT::datatable(
-    data = df[,-1], rownames = FALSE, escape = FALSE, filter = 'top',
+    data = df, rownames = FALSE, escape = FALSE, filter = 'top',
     options = list(
       dom = "fti", pageLength = -1, ordering = FALSE, search = list(regex = TRUE)
     ),
     selection = 'none'
   )
+
+  dt <- DT::formatStyle(dt, 'idx', fontFamily = 'monospace')
+
   return(dt)
 }
