@@ -6,7 +6,7 @@
 #'
 #' @export
 #' @importFrom golem with_golem_options
-run_app <- function(onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ...) {
+run_app <- function(onStart = NULL, options = list("port" = 3838), enableBookmarking = NULL, uiPattern = "/", ...) {
   golem::with_golem_options(
     app = shiny::shinyApp(
       ui = app_ui,
