@@ -16,7 +16,7 @@ testthat::test_that(
     testthat::expect_true(all(sapply(tab[,c("Analyte", "Level")], is.factor)))
 
     # check if statistics on import data works
-    out <- plyr::ldply(levels(tab[,"Analyte"]), function(a) {
+    out <- ldply_base(levels(tab[,"Analyte"]), function(a) {
         eCerto:::prepTabV1(tab = tab, a = a)
     })
     testthat::expect_true(is.data.frame(out))
@@ -28,6 +28,8 @@ testthat::test_that(
     testthat::expect_true(inherits(out_styled, "datatables"))
 
     # check generation of Fig.V1
+    skip_if_not_linux_ci()
+
     ab <- eCerto:::prepDataV1(tab = tab)
     testthat::expect_true(length(ab)==8)
     ab <- eCerto:::prepDataV1(tab = tab, fmt = "norm")
